function ksi_a = MVIndex(dT,delay,sysc,sysp,sysd) ;

% KSI_A = MVIndex(DT,DELAY,SYSC,SYSP,SYSD);
%
% Estimation of Minimun Variance based Index (MVI) from a known
% controller, process and disturbance models.
%
% KSI_r     = Estimated values of MVC index 
%
% DT        = Sampling time
% DELAY     = Number of process unit delays.
% SYSC      = Controller model
% SYSP      = Process model
% SYSD      = Disturbance model
%
%
% --------------------------------------------------------------------
% -                              -
% -                                             -
% -                                                  -
% - ... "           -
% -                                                                  -
% -                                                                  -
% -                        -
% -                                                                  -
% - : "        -
% -          "                          -
% -                                                                  -
% -  : 2014-15                                          -
% -                                                                  -
% -                                                                  -
% --------------------------------------------------------------------
% -                                                                  -
% - : "MVIndex.M"                                           -
% -                                                                  -
% - :             -
% -            (Minimun Variance Index)            -
% -                 (DELAY), -
% -            (SYSP),  (SYSC)   (SYSD) -
% -                                                                  -
% -                                                                  -
% --------------------------------------------------------------------

	  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Identification of System Models
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[numc,denc]=tfdata(sysc,'v');
[nump,denp,dumm]=tfdata(sysp,'v');
[numd,dend]=tfdata(sysd,'v');

delays=delay/dT;

   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % Estimation of MVC-based Index
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
		% Fix inputs
        T=0:dT:(1000*dT-dT);
		  T=T';
        Us=ones(1,1000);
		  Us(1:5)=zeros(1,5);
		  Ui=zeros(1,1000);
		  Ui(2:3)=[1 1];
		  Us=(Us)';
		  Ui=Ui';
        st=zeros(1,length(T));		  
	
	% Calculate impulse response coefficients of CL e to y for approximate system:
	% with no set-point change

		[num1c,den1c]=feedback(conv(numc,nump),conv(denc,denp),[1],[1],-1);
		[num2c,den2c]=feedback([1],[1],conv(numc,nump),conv(denc,denp),-1);
		num3c=conv([1 0],num2c);
		den3c=conv(dend,den2c);
		[y1,x1]=dlsim(num3c,den3c,Ui);
		[y2,x2]=dlsim(num1c,den1c,st);
		yaim_wn=y1+y2;

		clear num1c den1c num2c den2c num3c den3c y1 x1 y2 x2;
        plot(yaim_wn)
   % Calculate the variance of the output of approximate model w/o control (open loop)
		[ya_ol,xi]=lsim(tf(numd,dend,dT),Ui);

	% Calulculate the impulse response coefficients of the original disturbance
	% transfer function Yo and approximate one Ya
            Ya=yaim_wn(2:500,1);
            mvYa=Ya(1:delays-1);
      
   % For the approximate model
			var_yta=1+norm(Ya)^2;
			var_mva=1+norm(mvYa)^2;
			var_ola=1+norm(ya_ol)^2;
			ksi_a=var_yta/var_mva;
                                  
  		clear Yo mvYo mvYa n_norm var_yto var_mvo var_olo
		clear var_yta var_ola var_mva i1 i2 ya_ol yo_ol yaim_wn yoim_wn xopa 
		clear ek s pseudo re Vxsd xs ea Xoi_wn 
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% End of Estimation of MVC-based Index
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
